@@ -1,5 +1,6 @@
 from __future__ import absolute_import
-from . import base_classes
-from . import nsga3
+from . import base
 from . import helpers
-from . import sode
\ No newline at end of file
+from . import DOE
+from . import nsga3
+from . import sode
